@@ -3,29 +3,35 @@ from ..true_measure._true_measure import TrueMeasure
 from ..discrete_distribution._discrete_distribution import DiscreteDistribution
 from numpy import *
 import os
-import multiprocessing
+from multiprocessing import get_context
+from multiprocessing.pool import ThreadPool
 from itertools import repeat
 
 
 class Integrand(object):
     """ Integrand abstract class. DO NOT INSTANTIATE. """
 
-    def __init__(self, dprime, parallel):
+    def __init__(self, dimension_indv, dimension_comb, parallel, threadpool=False):
         """
         Args:
-            dprime (tuple): function output dimension shape.
+            dimension_indv (tuple): individual solution shape.
+            dimension_comb (tuple): combined solution shape. 
             parallel (int): If parallel is False, 0, or 1: function evaluation is done in serial fashion.
-                Otherwise, parallel specifies the number of CPUs used by multiprocessing.Pool.
-                Passing parallel=True sets the number of CPUs equal to os.cpu_count().
+                Otherwise, parallel specifies the number of processes used by 
+                multiprocessing.Pool or multiprocessing.pool.ThreadPool.
+                Passing parallel=True sets processes = os.cpu_count().
+            threadpool (bool): When parallel > 1, 
+                if threadpool = True then use multiprocessing.pool.ThreadPool 
+                else use multiprocessing.Pool. 
         """
         prefix = 'A concrete implementation of Integrand must have '
         self.d = self.true_measure.d
-        self.dprime = (dprime,) if isinstance(dprime,int) else tuple(dprime)
+        self.d_indv = (dimension_indv,) if isinstance(dimension_indv,int) else tuple(dimension_indv)
+        self.d_comb = (dimension_comb,) if isinstance(dimension_comb,int) else tuple(dimension_comb)
         cpus = os.cpu_count()
         self.parallel = cpus if parallel is True else int(parallel)
         self.parallel = 0 if self.parallel==1 else self.parallel
-        if self.parallel>cpus:
-            raise ParameterError("parallel must be less than %d, the number of CPUs on this machine."%cpus)
+        self.threadpool = threadpool
         if not (hasattr(self, 'sampler') and isinstance(self.sampler,(TrueMeasure,DiscreteDistribution))):
             raise ParameterError(prefix + 'self.sampler, a TrueMeasure or DiscreteDistributioninstance')
         if not (hasattr(self, 'true_measure') and isinstance(self.true_measure,TrueMeasure)):
@@ -43,12 +49,16 @@ class Integrand(object):
             raise ParameterError("The range of the composed transform is not compatibe with this true measure")
         self.EPS = finfo(float).eps
 
-    def g(self, t, *args, **kwargs):
+    def g(self, t, compute_flags=None, *args, **kwargs):
         """
         ABSTRACT METHOD for original integrand to be integrated.
 
         Args:
             t (ndarray): n x d array of samples to be input into original integrand.
+            compute_flags (ndarray): outputs that require computation. 
+                For example, if the vector function has 3 outputs and compute_flags = [False, True, False], 
+                then the function is only required to compute the second output and may leave the remaining outputs as e.g. 0. 
+                The False outputs will not be used in the computation since those integrals have been sufficiently approximated.
 
         Return:
             ndarray: n vector of function evaluations
@@ -62,7 +72,10 @@ class Integrand(object):
         Args:
             x (ndarray): n x d array of samples from a discrete distribution
             periodization_transform (str): periodization transform
-            compute_flags (ndarray): TODO
+            compute_flags (ndarray): outputs that require computation. 
+                For example, if the vector function has 3 outputs and compute_flags = [False, True, False], 
+                then the function is only required to compute the second output and may leave the remaining outputs as e.g. 0. 
+                The False outputs will not be used in the computation since those integrals have been sufficiently approximated.
             *args: other ordered args to g
             **kwargs (dict): other keyword args to g
 
@@ -70,7 +83,7 @@ class Integrand(object):
             ndarray: length n vector of function evaluations
         """
         periodization_transform = 'NONE' if periodization_transform is None else periodization_transform.upper()
-        compute_flags = tile(1,self.dprime) if compute_flags is None else atleast_1d(compute_flags)
+        compute_flags = tile(1,self.d_indv) if compute_flags is None else atleast_1d(compute_flags)
         n,d = x.shape
         # parameter checks
         if self.discrete_distrib.mimics != 'StdUniform' and periodization_transform!='NONE':
@@ -106,7 +119,7 @@ class Integrand(object):
             xp[xp<=0] = self.EPS
             xp[xp>=1] = 1-self.EPS
         # function evaluation with chain rule
-        y = empty((n,)+self.dprime,dtype=float)
+        y = empty((n,)+self.d_indv,dtype=float)
         if self.true_measure == self.true_measure.transform:
             # jacobian*weight/pdf will cancel so f(x) = g(\Psi(x))
             xtf = self.true_measure._transform(xp) # get transformed samples, equivalent to self.true_measure._transform_r(x)
@@ -119,26 +132,27 @@ class Integrand(object):
             gvals = self._g(xtf,compute_flags,*args,**kwargs)
             for i in range(n): y[i] = gvals[i]*weight[i]/pdf[i]*jacobians[i]
         # account for periodization weight
-        for i in range(n): y[i] = y[i]*wp[i]
+        y = (y.T*wp).T
         return y
 
     def _g(self,t,compute_flags,*args,**kwargs):
         n = len(t)
         kwargs['compute_flags'] = compute_flags
         if self.parallel:
-            pool = multiprocessing.Pool(processes=self.parallel)
+            pool = get_context(method='fork').Pool(processes=self.parallel) if self.threadpool==False else ThreadPool(processes=self.parallel) 
             y = pool.starmap(self._g2,zip(t,repeat((args,kwargs))))
+            pool.close()
             y = concatenate(y,dtype=float)
         else:
             y = self._g2(t,comb_args=(args,kwargs))
-        y = y.reshape((n,)+self.dprime)
+        y = y.reshape((n,)+self.d_indv)
         return y
 
     def _g2(self,t,comb_args=((),{})):
         args = comb_args[0]
         kwargs = comb_args[1]
         t = atleast_2d(t)
-        if self.dprime==(1,):
+        if self.d_indv==(1,):
             kwargs = dict(kwargs)
             del kwargs['compute_flags']
         y = self.g(t,*args,**kwargs)
@@ -152,8 +166,8 @@ class Integrand(object):
         individually.
 
         Args:
-            bound_low (ndarray): length Integrand.dprime lower error bound
-            bound_high (ndarray): length Integrand.dprime upper error bound
+            bound_low (ndarray): length Integrand.d_indv lower error bound
+            bound_high (ndarray): length Integrand.d_indv upper error bound
 
         Return:
             (tuple) containing
@@ -162,21 +176,28 @@ class Integrand(object):
             - (ndarray): upper bound on function combining estimates
             - (ndarray): bool flags to override sufficient combined integrand estimation, e.g., when approximating a ratio of integrals, if the denominator's bounds straddle 0, then returning True here forces ratio to be flagged as insufficiently approximated.
         """
-        return bound_low, bound_high, array([False])
+        if self.d_indv!=self.d_comb:
+            raise ParameterError('''
+                Set bound_fun explicity. 
+                The default bound_fun is the identity map. 
+                Since individual solution dimension d_indv != combined solution dimension d_comb, 
+                QMCPy cannot infer a reasonable bound function.''')
+        return bound_low,bound_high
 
-    def dependency(self, flags_comb):
+    def dependency(self, comb_flags):
         """
-        takes a vector of indicators of weather of not
+        Takes a vector of indicators of weather of not
         the error bound is satisfied for combined integrands and which returns flags for individual integrands.
         For example, if we are taking the ratio of 2 individual integrands, then getting flag_comb=True means the ratio
         has not been approximated to within the tolerance, so the dependency function should return [True,True]
         indicating that both the numerator and denominator integrands need to be better approximated.
         Args:
-            flags_comb (bool ndarray): flags indicating weather the combined integrals are insufficiently approximated
+            comb_flags (bool ndarray): flags indicating weather the combined integrals are insufficiently approximated
 
         Return:
-            (bool ndarray): length (Integrand.dprime) flags for individual integrands"""
-        return flags_comb
+            (bool ndarray): length (Integrand.d_indv) flags for individual integrands
+        """
+        return comb_flags if self.d_indv==self.d_comb else  tile((comb_flags==False).any(),self.d_indv)
 
     def _dimension_at_level(self, level):
         """
