@@ -1,18 +1,18 @@
-""" Math functions used across various algorithms """
+""" Math functions used across various algorithms. """
 
-def tolfun(abs_tol, rel_tol, theta, mu, toltype):
+def _tol_fun(abs_tol, rel_tol, theta, mu, toltype):
     """
     Generalized error tolerance function.
 
-    Args: 
+    Args:
         abs_tol (float): absolute error tolertance
         rel_tol (float): relative error tolerance
         theta (float): parameter in 'theta' case
         mu (loat): true mean
         toltype (str): different options of tolerance function
-    
+
     Return:
-        float: tolerence as weighted sum of absolute and relative tolerence
+        float: tolerance as weighted sum of absolute and relative tolerance
     """
     if toltype == 'combine':  # the linear combination of two tolerances
         # theta == 0 --> relative error tolarance
